internal,reflect: correct typos

Fix typos in comments and unexported function name.

Change-Id: I239fff85bc68d7f0ef6f8853acdc9bbe19d86304
Reviewed-on: https://go-review.googlesource.com/c/protobuf/+/466535
Reviewed-by: Lasse Folger <[email protected]>
Reviewed-by: Michael Stapelberg <[email protected]>
Reviewed-by: Joseph Tsai <[email protected]>
diff --git a/integration_test.go b/integration_test.go
index 33ac34d..e73ad24 100644
--- a/integration_test.go
+++ b/integration_test.go
@@ -146,7 +146,7 @@
 		checks := []string{
 			"all",     // start with all checks enabled
 			"-SA1019", // disable deprecated usage check
-			"-S*",     // disable code simplication checks
+			"-S*",     // disable code simplification checks
 			"-ST*",    // disable coding style checks
 			"-U*",     // disable unused declaration checks
 		}
diff --git a/internal/encoding/json/decode.go b/internal/encoding/json/decode.go
index b13fd29..d043a6e 100644
--- a/internal/encoding/json/decode.go
+++ b/internal/encoding/json/decode.go
@@ -294,7 +294,7 @@
 }
 
 // consumeToken constructs a Token for given Kind with raw value derived from
-// current d.in and given size, and consumes the given size-lenght of it.
+// current d.in and given size, and consumes the given size-length of it.
 func (d *Decoder) consumeToken(kind Kind, size int) Token {
 	tok := Token{
 		kind: kind,
diff --git a/reflect/protoreflect/value.go b/reflect/protoreflect/value.go
index f319810..37601b7 100644
--- a/reflect/protoreflect/value.go
+++ b/reflect/protoreflect/value.go
@@ -148,7 +148,7 @@
 	// be preserved in marshaling or other operations.
 	IsValid() bool
 
-	// ProtoMethods returns optional fast-path implementions of various operations.
+	// ProtoMethods returns optional fast-path implementations of various operations.
 	// This method may return nil.
 	//
 	// The returned methods type is identical to
diff --git a/internal/cmd/generate-protos/main.go b/internal/cmd/generate-protos/main.go
index fbb1be9..37f50d3 100644
--- a/internal/cmd/generate-protos/main.go
+++ b/internal/cmd/generate-protos/main.go
@@ -53,7 +53,7 @@
 					gengo.GenerateVersionMarkers = false
 					gengo.GenerateFile(gen, file)
 					generateIdentifiers(gen, file)
-					generateSouceContextStringer(gen, file)
+					generateSourceContextStringer(gen, file)
 				}
 			}
 			gen.SupportedFeatures = gengo.SupportedFeatures
@@ -324,10 +324,10 @@
 	processMessages(file.Messages)
 }
 
 // generateSouceContextStringer generates the implementation for the
 // protoreflect.SourcePath.String method by using information present
 // in the descriptor.proto.
-func generateSouceContextStringer(gen *protogen.Plugin, file *protogen.File) {
+func generateSourceContextStringer(gen *protogen.Plugin, file *protogen.File) {
 	if file.Desc.Path() != "google/protobuf/descriptor.proto" {
 		return
 	}
@@ -324,10 +324,10 @@
 }
 
-// generateSouceContextStringer generates the implementation for the
+// generateSourceContextStringer generates the implementation for the
 // protoreflect.SourcePath.String method by using information present
 // in the descriptor.proto.